==> patternfly-java-components-0.2.8-sources.jar: org/patternfly/component/tabs/TabContentBody.java <==
/*
 *  Copyright 2023 Red Hat
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.patternfly.component.tabs;

import org.patternfly.style.Modifiers.Padding;

import elemental2.dom.HTMLElement;

import static org.jboss.elemento.Elements.div;
import static org.patternfly.style.Classes.body;
import static org.patternfly.style.Classes.component;
import static org.patternfly.style.Classes.tabContent;

public class TabContentBody extends TabSubComponent<HTMLElement, TabContentBody>
        implements Padding<HTMLElement, TabContentBody> {

    // ------------------------------------------------------ factory

    public static TabContentBody tabContentBody() {
        return new TabContentBody();
    }

    // ------------------------------------------------------ instance

    static final String SUB_COMPONENT_NAME = "tcb";

    TabContentBody() {
        super(SUB_COMPONENT_NAME, div().css(component(tabContent, body))
                .element());
    }

    // ------------------------------------------------------ builder

    @Override
    public TabContentBody that() {
        return this;
    }
}

==> patternfly-java-components-0.4.4-sources.jar: org/patternfly/component/tabs/TabContentBody.java <==
/*
 *  Copyright 2023 Red Hat
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.patternfly.component.tabs;

import org.jboss.elemento.ElementTextMethods;
import org.patternfly.style.Modifiers.Padding;

import elemental2.dom.HTMLElement;

import static org.jboss.elemento.Elements.div;
import static org.patternfly.style.Classes.body;
import static org.patternfly.style.Classes.component;
import static org.patternfly.style.Classes.tabContent;

public class TabContentBody extends TabSubComponent<HTMLElement, TabContentBody> implements
        ElementTextMethods<HTMLElement, TabContentBody>,
        Padding<HTMLElement, TabContentBody> {

    // ------------------------------------------------------ factory

    public static TabContentBody tabContentBody() {
        return new TabContentBody();
    }

    // ------------------------------------------------------ instance

    public static final String SUB_COMPONENT_NAME = "tcb";

    TabContentBody() {
        super(SUB_COMPONENT_NAME, div().css(component(tabContent, body))
                .element());
    }

    // ------------------------------------------------------ builder

    @Override
    public TabContentBody that() {
        return this;
    }
}
